@@ -25,16 +25,21 @@ class Transformation:
         name: str,
         query: str,
         version: str,
-        static: bool = False,
+        static: bool = True,
         has_output: bool = False,
         destination_table: str = None,
+        keep_old_columns: bool = True,
+        persist_backup: bool = True,
         write_disposition: WriteDisposition = WriteDisposition.APPEND,
         time_partitioning: dict = None,
         cluster_fields: List[str] = None,
         schema_update_options: List[SchemaUpdateOptions] = [
             SchemaUpdateOptions.ALLOW_FIELD_ADDITION
         ],
+        destination_data_mart: str = None,
         dependencies: List[dict] = None,
+        parsing_dependencies: List[dict] = None,
+        destroy_table: bool = False,
         tables: List[dict] = None,
     ):
         """Class representing a transformation.
@@ -51,6 +56,10 @@ class Transformation:
         :type has_output: bool, optional
         :param destination_table: [description], defaults to None
         :type destination_table: str, optional
+        :param keep_old_columns:
+        :type keep_old_columns: bool, optional
+        :param persist_backup:
+        :type persist_backup: bool, optional
         :param write_disposition: The write disposition for writing the results, defaults to WriteDisposition.APPEND
         :type write_disposition: WriteDisposition, optional
         :param time_partitioning: An dictionary with the time partition configuration, defaults to None
@@ -59,8 +68,14 @@ class Transformation:
         :type cluster_fields: List[str], optional
         :param schema_update_options: Whether or not the schema can be changed by adding fields, defaults to [ SchemaUpdateOptions.ALLOW_FIELD_ADDITION ]
         :type schema_update_options: List[SchemaUpdateOptions], optional
+        :param destination_data_mart: Alias of the table to use for data mart
+        :type destination_data_mart: str
         :param dependencies: This allows you to set hard dependencies on your queries, defaults to None
         :type dependencies: List[dict], optional
+        :param parsing_dependencies:
+        :type parsing_dependencies: List[dict], optional
+        :param destroy_table: If True, the resulting table of this transformation will be destroy and recreated automatically. Only works in sandbox environment.
+        :type destroy_table: bool, default to False
         :param tables: If specified, this transformation will generate multiple BigQueryOperator during Airflow generation, one for each table name in this list.
                        The name of the transformation then becomes `{transformation_name}_{table_name}`
         :type tables: List[str], optional
@@ -71,11 +86,16 @@ class Transformation:
         self.static = static
         self.has_output = has_output
         self.destination_table = destination_table
+        self.keep_old_columns = keep_old_columns
+        self.persist_backup = persist_backup
         self.write_disposition = write_disposition
         self.time_partitioning = time_partitioning
         self.cluster_fields = cluster_fields
         self.schema_update_options = schema_update_options
+        self.destination_data_mart = destination_data_mart
         self.dependencies = dependencies
+        self.parsing_dependencies = parsing_dependencies
+        self.destroy_table = destroy_table
         self.tables = tables
 
     @classmethod
@@ -88,19 +108,26 @@ class Transformation:
         :rtype: Transformation
         """
         return Transformation(
-            name=d["NAME"],
+            name=d.get("NAME", ""),
             query=d["QUERY"],
             version=d["VERSION"],
-            static=d.get("STATIC", False),
-            has_output=d.get("HAS_OUTPUT", False),
+            static=d.get("STATIC", True),
+            has_output=d.get("HAS_OUTPUT", True),
             destination_table=d.get("DESTINATION_TABLE"),
-            write_disposition=WriteDisposition(d.get("WRITE_DISPOSITION")),
+            keep_old_columns=d.get("KEEP_OLD_COLUMNS", True),
+            persist_backup=d.get("PERSIST_BACKUP", True),
+            write_disposition=WriteDisposition(
+                d.get("WRITE_DISPOSITION", "WRITE_APPEND")
+            ),
             time_partitioning=d.get("TIME_PARTITIONING"),
-            cluster_fields=d.get("CLUSTER_FIELDS", []),
+            cluster_fields=d.get("CLUSTER_FIELDS"),
             schema_update_options=[
-                SchemaUpdateOptions(x) for x in d["SCHEMA_UPDATE_OPTIONS"]
+                SchemaUpdateOptions(x) for x in d.get("SCHEMA_UPDATE_OPTIONS", [])
             ],
+            destination_data_mart=d.get("DESTINATION_DATA_MART"),
             dependencies=d.get("DEPENDS_ON", []),
+            parsing_dependencies=d.get("PARSING_DEPENDS_ON", []),
+            destroy_table=d.get("DESTROY_TABLE", False),
             tables=d.get("TABLES"),
         )
 
@@ -118,11 +145,18 @@ class Transformation:
             "STATIC": self.static,
             "HAS_OUTPUT": self.has_output,
             "DESTINATION_TABLE": self.destination_table,
+            "KEEP_OLD_COLUMNS": self.keep_old_columns,
+            "PERSIST_BACKUP": self.persist_backup,
             "WRITE_DISPOSITION": self.write_disposition.value,
             "TIME_PARTITIONING": self.time_partitioning,
             "CLUSTER_FIELDS": self.cluster_fields,
-            "SCHEMA_UPDATE_OPTIONS": [o.value for o in self.schema_update_options],
+            "SCHEMA_UPDATE_OPTIONS": [
+                o.value for o in self.schema_update_options or []
+            ],
+            "DESTINATION_DATA_MART": self.destination_data_mart,
             "DEPENDS_ON": self.dependencies,
+            "PARSING_DEPENDS_ON": self.parsing_dependencies,
+            "DESTROY_TABLE": self.destroy_table,
             "TABLES": self.tables,
         }
 
@@ -135,10 +169,15 @@ class Transformation:
             and self.static == other.static
             and self.has_output == other.has_output
             and self.destination_table == other.destination_table
+            and self.keep_old_columns == other.keep_old_columns
+            and self.persist_backup == other.persist_backup
             and self.write_disposition == other.write_disposition
             and self.time_partitioning == other.time_partitioning
             and self.cluster_fields == other.cluster_fields
             and self.schema_update_options == other.schema_update_options
+            and self.destination_data_mart == other.destination_data_mart
             and self.dependencies == other.dependencies
+            and self.parsing_dependencies == other.parsing_dependencies
+            and self.destroy_table == other.destroy_table
             and self.tables == other.tables
         )
